"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildExecutor = void 0;
const tslib_1 = require("tslib");
const webpack_impl_1 = require("@nrwl/node/src/executors/webpack/webpack.impl");
const project_graph_1 = require("@nrwl/workspace/src/core/project-graph");
const normalize_1 = require("@nrwl/node/src/utils/normalize");
const generate_package_json_1 = require("../../utils/generate-package-json");
const generate_package_json_lock_file_1 = require("../../utils/generate-package-json-lock-file");
function buildExecutor(rawOptions, context) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { sourceRoot, root } = context.workspace.projects[context.projectName];
        if (!sourceRoot) {
            throw new Error(`${context.projectName} does not have a sourceRoot.`);
        }
        if (!root) {
            throw new Error(`${context.projectName} does not have a root.`);
        }
        const options = (0, normalize_1.normalizeBuildOptions)(rawOptions, context.root, sourceRoot, root);
        const { value } = yield (0, webpack_impl_1.default)(rawOptions, context)
            .next();
        if (value.success) {
            (0, generate_package_json_1.generatePackageJson)(context.projectName, (0, project_graph_1.readCachedProjectGraph)(), options, value.outfile, context.root);
            if (rawOptions.generateLockFile) {
                (0, generate_package_json_lock_file_1.generatePackageJsonLockFile)(context.root, context.projectName, options);
            }
        }
        return value;
    });
}
exports.buildExecutor = buildExecutor;
exports.default = buildExecutor;
//# sourceMappingURL=build.impl.js.map